<div class="backImg"> <img id="bg" ng-src="{{albumImage}}" /></div>

<div class="main">
	<div style="height: 60px"></div>
	<div ng-if="!pageReady">
		<br><br><br>
		<i class="fa fa-spinner fa-2x fa-pulse"></i>
	</div> 
	
	<div  ng-if="pageReady">
	
		<div class="lfmInfo">
			<table width=100% height=180>
				<tr>
					<td width=180> <img ng-src="{{ albumImage }}" width=180 height=180> </td>
					<td valign="top"> <h2><h2>ALBUM BY : {{ album.artists[0].name | uppercase }} {{ album.date }}</h2></h2> </td>
				</tr>				
			</table>	
		</div>
			
		<div ng-repeat="track in tracks">
			<div class="box">
				<a href="" ng-click="contextMenu(track);">
					<div class="boxRight">
						<i class="fa fa-ellipsis-v fa-2x"></i>
					</div>
				</a>
				<a href="" ng-click="addReplacePlay( track, playlistUris, album )">				
					<div class="boxCenter" ng-if="track.uri != currentUri || currentUri === null"><div style="display: table; height: 56px;"><div style="display: table-cell; vertical-align: middle;">
						<h1>{{ track.name | shorten }}</h1>
						<h3>Track {{ track.track_no }}: {{ track.length | formatTime}}</h3>
					</div></div></div>
					<div class="boxCenter2" class="boxCenter2" ng-if="track.uri === currentUri"><div style="display: table; height: 56px;"><div style="display: table-cell; vertical-align: middle;">
						<h1>{{ track.name | shorten }}</h1>
						<h3>Track {{ track.track_no }}: {{ track.length | formatTime}}</h3>
					</div></div></div>
				</a>
			</div>					
		</div>
		
	</div>
	
	<br><br><br>
</div>
