<div class="backImg" ng-if="!showQueue"><img id="bg" ng-src="{{currentTrackImageUrl}}" /></div>

<div class="nowPlaying">
		<div style="height: 60px"></div>		
		
		<div class="nowPlayingTop">
			<table align="center" width="100%">
				<tr>
					<td width=30px align="left" valign="middle"> <a href="" ><i class="fa fa-volume-up" style="font-size: 20px;"></i></a> </td>	
					<td valign="middle"><p>{{ currentAlbum.name }}</p></td>
					<td width=30px align="right" valign="middle"><a href="#/nowplaying/queue" ><i class="fa fa-list-ul" style="font-size: 20px;"></i></a></td>
				</tr>
			</table>
		</div>
							
		<div class="albumImg">
			<table align="center" width="100%" height="100%">
				<tr>
					<td valign=middle><img ng-src="{{currentTrackImageUrl}}" /> </td>
				</tr>
			</table> 
		</div>
						
		<div class="playControls">
			<h1>{{ currentTrack }}</h1>
			<p>{{ currentArtists[0].name }}</p>
			<p>{{ currentTrackPosition }} / {{ currentTrackLengthString }}</p>
			<table width=100% align="center">
				<tr>
					<td width=10></td>
					<td align="left"><a href="" ng-click="previous()"><i class="fa fa-step-backward"></i></a></td>
					<td>
						<p ng-if="currentState != 'playing'"><a href="" ng-click="play()"><i class="fa fa-play" style="font-size: 50px;"></i></a></p>
						<p ng-if="currentState === 'playing'"><a href="" ng-click="play()"><i class="fa fa-pause" style="font-size: 50px;"></i></a></p>				
					</td>
					<td align="right"><a href="" ng-click="next()"><i class="fa fa-step-forward"></i></a></td>
					<td width=10></td>
					</tr>
			</table>			
		</div>

		<!-- PLAY QUEUE -->
		
		<div class="queueControl" ng-if="showQueue">
					
			<div ng-repeat="tracks in trackList">				
				<div class="box">
					<a href="" ng-click="queueMenu(tracks);">
						<div class="boxRight">
							<i class="fa fa-ellipsis-v fa-2x"></i>
						</div>
					</a>
					<a href="" ng-click="playTlTrack( tracks.tlid )">
						<div class="boxLeft"> 
							<img ng-src="{{tracks.lfmImage}}" width=50 height=50 />
						</div>			
						<div class="boxCenter" ng-if="tracks.tlid != currentTlid"><div style="display: table; height: 56px;"><div style="display: table-cell; vertical-align: middle;">
							<h1>{{ tracks.track.name | shorten:'':0 }}</h1>
							<h3>{{ tracks.track.artists[0].name }}</h3>
						</div></div></div>
						<div class="boxCenter2" ng-if="tracks.tlid === currentTlid"><div style="display: table; height: 56px;"><div style="display: table-cell; vertical-align: middle;">
							<h1>{{ tracks.track.name | shorten:'':0 }}</h1>
							<h3>{{ tracks.track.artists[0].name }}</h3>
						</div></div></div>
					</a>
				</div>
			</div>	
			
		</div>
		
		
		
</div>