/*
//
//   BOXES.
//
*/
.box {
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	overflow:hidden;
  height:56px;
  width: 95%;
  margin: auto;
	border-bottom-style: dotted;
	border-color: #999999;
	border-width: 1px;
	text-align: left;
}

.boxLeft {
	height:50px;
	width:56px;
	float:left;
	padding-top: 3px;
	text-align: left;
}
.boxLeftIcon {
	height:50px;
	width:56px;
	float:left;
	text-align: center;
	line-height: 65px;
	color: #888888;
}

.boxRight {
	height:56px;
 	width:30px;
  float:right;
  line-height: 68px;
  color: #666666;
  text-align: center;
}

.boxCenter {
	width: 100%;
	height: 100%
	text-align: left;
	//padding-left: 5px;
}
.boxCenter2 {
	width: 100%;
	height: 100%;
	text-align: left;
	//padding-left: 5px;
}
.boxCenter2 h1 {
	color: lightgreen !important;
}
.box h1 {
	color: #FFFFFF;
	font-size: 17px;
	font-weight: 100;
	line-height: 3px;
}
.box h3 {
	color: #999999;
	font-size: 12px;
	font-weight: 100;
	line-height: 0px;
}

/*
//
//   OTHER BOXES.
//
*/

.box3{
	width: 95%;
  margin-left:auto;
  margin-right:auto;
  height: 56px;
	border-bottom-style: dotted;
	border-color: #999999;
	border-width: 1px;
	text-align:left;
	
}
.box3 h1{
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	font-size: 17px;
	font-weight: 400;
	color: #777777;
	line-height: 85px;
}
.box2{
	width: 95%;
  margin-left:auto;
  margin-right:auto;
  height: 35px;
	border-bottom-style: dotted;
	border-color: #999999;
	border-width: 1px;
	text-align:left;
	padding-left: 6px;
}
.box2 h1{
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	font-size: 17px;
	font-weight: 400;
	color: #777777;
}

/*
//
// CONTEXT MENU
//
*/

.contextMenu {
	//display: none;
	position: fixed;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;	
}
.contextMask {
	position: fixed;
	width: 100%;
	height: 100%;
	background-color: black;
	opacity: 0.5;
}
.contextOuter {
	top: 50%;
  left: 50%;
  position: absolute;
}
.contextInner {
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	font-size: 13px;
	font-weight: 600;
	
	position: relative;
	width: 300px;
	margin-left: -150px;
	height: 400px;
	margin-top: -200px;
	background: black;
	border-style: solid;
	border-width: 1px;
	text-align: center;
	padding: 3px;
}

/*
//
// SEARCH AND MENU
//
*/

.menumask {
	display: 		none;
	opacity:    0.5; 
  background: #000; 
  width:      100%;
  height:     100%; 
  z-index:    999;
  top:        0; 
  left:       0; 
  position:   fixed; 
}
input:-webkit-autofill,
input:-webkit-autofill:hover,
input:-webkit-autofill:focus,
input:-webkit-autofill:active {
    -webkit-transition: "color 9999s ease-out, background-color 9999s ease-out";
    -webkit-transition-delay: 9999s;
}
input:focus {
   outline: none;
}

.searchBox, .searchBox active, .searchBox hover {
	-webkit-appearance: none;
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	font-size: 17px;
	background: transparent;
	padding:4px 4px 4px 4px;
	margin: 0px;
	border:0px;
	border-bottom: 1px solid #555555;
	width:230px;
	height:18px;
	color: #ffffff
}
.searchButton {
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	background: transparent;
	border: 0px solid #555555;
	color: #FFFFFF;
}

.lfmInfo {
	width: 95%;
	margin:auto;
}

.lfmInfo h2 {
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	color: #ffffff;
	font-size: 11px;
	font-style: normal;
	font-variant: normal;
	font-weight: 200;
	line-height: 11px;	
}

/*
//
// BODY AND BACKGROUNDS
//
*/

body {
  background-color: #000000;
  color: #FFFFFF;
  padding: 0px;
	margin: 0px;
} 
body div {
	padding: 0px;
	margin: 0px;
}

body a {
    text-decoration: none;
}


.main {
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
  text-align: center;
  width: 100%;
  height: 100%;
  padding: 0px;
	margin: 0px;

}

.backImg {
	background-color: black;
	position: fixed;
  overflow: hidden;
	z-index: -1;

	width: 10%;
	height: 10%;

	-webkit-transform-origin: top left;
	-webkit-transform: scale(10) !important;
	-webkit-perspective: 1000;
	-webkit-backface-visibility: hidden;
	-webkit-transform: translateZ(0);

	transform-origin: top left;
	transform: scale(10);
}
#bg{
	width: 100%;
	height: 100%;
	
	-webkit-filter: blur(7px) brightness(0.6);
  -webkit-perspective: 1000;
	-webkit-backface-visibility: hidden;
	-webkit-transform: translateZ(0);
	
	filter: blur(7px) brightness(0.6);
	
}

/*
//
// NOW PLAYING AND QUEUE
//
*/

.nowPlaying {
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
  text-align: center;
  width: 100%;
  height: 100%;
  padding: 0px;
	margin: 0px;
}
.nowPlaying h1 {
	color: #FFFFFF;
	font-size: 17px;
	font-weight: 100;
	line-height: 3px;
}
.nowPlaying h3 {
	color: #ffffff;
	font-size: 12px;
	font-weight: 100;
	line-height: 0px;
}
.nowPlaying p {
	color: #999999;
	font-size: 14px;
	font-weight: 100;
	line-height: 0px;
}
.nowPlaying a {
		color: #ffffff;
}

.playControls {
  position: fixed;
	left: 0;
  right: 0;
  bottom: 0;
  height: 150px;
  padding: 0px;
  margin: 0px;
}
.playControls table{
	font-size: 30px;
	text-decoration: none;
	letter-spacing: 0px;
	max-width:700px;
	line-height: 0px;
	padding: 0px
}
.nowPlayingTop table{
	max-width: 700px;
}

.nowPlayingTop {
	height: 45px;
	width: 100%;
}
.albumImg {
	position:fixed;
	left: 0;
  right: 0;
  top: 100px;
  bottom:150px 
}
.albumImg img{
  height: 300px;
  max-Height: 100%
}

.queueControl{
	background: #000000;
	opacity: 0.9;
	position: absolute;
	width: 100%;
	min-height: 100%;
	top: 50px;
	padding: 0px;
	margin: 0px;
}

/*
//
// HEADERS AND FOOTERS
//
*/

.header {
	background: rgb(22, 22, 22);
	background: rgba(22, 22, 22, 0.4);
	position: fixed;
  left: 0;
  right: 0;
  top: 0;
  height: 50px;
}

.header h1 {
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	color: #ffffff;
	font-size: 16px;
	font-style: normal;
	font-variant: normal;
	font-weight: 700;
	line-height: 0px;
}

.header a{
	color: #ffffff;
	font-size: 25px;
	text-decoration: none;
}

.footer {
	/* Permalink - use to edit and share this gradient: http://colorzilla.com/gradient-editor/#515151+0,0e0e0e+100 */
	background: #515151; /* Old browsers */
	background: -moz-linear-gradient(top, #515151 0%, #0e0e0e 100%); /* FF3.6+ */
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#515151), color-stop(100%,#0e0e0e)); /* Chrome,Safari4+ */
	background: -webkit-linear-gradient(top, #515151 0%,#0e0e0e 100%); /* Chrome10+,Safari5.1+ */
	background: -o-linear-gradient(top, #515151 0%,#0e0e0e 100%); /* Opera 11.10+ */
	background: -ms-linear-gradient(top, #515151 0%,#0e0e0e 100%); /* IE10+ */
	background: linear-gradient(to bottom, #515151 0%,#0e0e0e 100%); /* W3C */
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#515151', endColorstr='#0e0e0e',GradientType=0 ); /* IE6-9 */
  color: #ffffff;
  position: fixed;
  left: 0;
  right: 0;
  bottom: 0;
  height: 50px;   
}
.footer h1 {
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	color: #FFFFFF;
	font-size: 16px;
	font-style: normal;
	font-variant: normal;
	font-weight: 400;
	line-height: 10px;
}
.footer h3 {
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	color: #888888;
	font-size: 11px;
	font-style: normal;
	font-variant: normal;
	font-weight: 200;
	line-height: 0px;
}

.footer_right {
  position: absolute;
  color: #FFFFFF;
  right: 0px;
  width: 60px;
  padding: 8px;
  text-align:right;
  text-decoration: none;
}

.footer_right a{
  color: #FFFFFF;
  font-size:30px;
  font-weight: 100;
  line-height: 0px;
}

.footer_left {
  position: absolute;
  left: 0px;
  width: 50px;
  padding: 0px;
}

.footer_center {
  position: absolute;
  width: 100%;
  top:0px;
  padding: 0px;
  text-align: center;
}

